@@ -1,11 +1,11 @@
-from .. import siesta
+from ... import siesta
 import json
 import base64
 import librosa
 from io import BytesIO
 import soundfile
 import os
-from .. import pathtool
+from ... import pathtool
 
 def resampling (audioFilePath):
     y, sr = librosa.load (audioFilePath, sr = 22050, mono = True)
@@ -14,14 +14,11 @@ def resampling (audioFilePath):
        return f.getvalue ()
    
 openApiURL = "http://aiopen.etri.re.kr:8000"
-ACCESS_KEY = None
 API = siesta.API (openApiURL)
 
-def set_access_key (key):
-    global ACCESS_KEY    
-    ACCESS_KEY = key
-
-def get_speech (audioFilePath, lang = "english"):
+def get_speech (audioFilePath, lang = "korean"):
+    from . import ACCESS_KEY
+    
     audioContents = base64.b64encode (resampling (audioFilePath)).decode("utf8")
     requestJson = {
         "access_key": ACCESS_KEY,
@@ -32,4 +29,9 @@ def get_speech (audioFilePath, lang = "english"):
         requestJson,
         {"Content-Type": "application/json; charset=UTF-8"}     
     )
-    return resp
+    try:
+        assert resp.status_code == 200
+        text = resp.data ['return_object']['recognized']
+    except (AssertionError, KeyError):
+        return ''
+    return text
